Changes in sphinx-astropy
=========================

1.1 (2018-11-15)
----------------

- Added a new extension for controlling whether intersphinx is used on the command-line.

- Added a new extension to give a clear warning if the _static folder is missing.

1.0 (2018-02-07)
----------------

- Initial standalone version of this package (formerly packaged as part of astropy-helpers)
